# vim: set sw=4 ts=4 et nu:
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/

Name:           mpd
Version:        0.17.5
Release:        3.2
License:        GPL-3.0+
Summary:        Music Player Daemon
Url:            http://www.musicpd.org/
Group:          Productivity/Multimedia/Sound/Players
Source:         http://www.musicpd.org/download/mpd/0.17/mpd-%{version}.tar.xz
Source1:        %{name}.init
Source2:        README.%{name}
Source3:        mpd-user.conf
Source4:        mpd.service
# PATCH-FEATURE-OPENSUSE -- mpd-mpdconf_suse.patch
Patch0:         %{name}-mpdconf_suse.patch
# PATCH-FIX-OPENSUSE -- mpd-wavpack.patch
Patch1:         %{name}-wavpack.patch
Patch2:         mpd-sndfile-vorbis.patch
# PATCH-FIX-PMBS -- mpd-0.17.4-ffmpeg2.patch - from gentoo
Patch10:	mpd-0.17.4-ffmpeg2.patch
BuildRequires:  alsa-devel
BuildRequires:  audiofile-devel
BuildRequires:  cdrkit-cdrtools-compat
BuildRequires:  faad2-devel
BuildRequires:  flac-devel
BuildRequires:  gcc-c++
BuildRequires:  libao-devel
BuildRequires:  libavahi-devel
BuildRequires:  libavahi-glib-devel
BuildRequires:  libcdio-devel
%if 0%{?suse_version} >= 1220
BuildRequires:  libcdio-paranoia-devel
%endif
BuildRequires:  libcue-devel
BuildRequires:  libcurl-devel
BuildRequires:  libffmpeg-devel
BuildRequires:  libsndfile-devel
%if 0%{?suse_version} >= 1230
BuildRequires:  pkgconfig(bzip2) 
%endif
BuildRequires:  tcpd-devel
BuildRequires:  glib2-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} > 1100
%if 0%{?suse_version} <= 1130
BuildRequires:  fluidsynth-devel
%else
BuildRequires:  libfluidsynth-devel
%endif
%endif
BuildRequires:  libid3tag-devel
BuildRequires:  libjack-devel
BuildRequires:  libmad-devel
BuildRequires:  libmikmod-devel
BuildRequires:  libmms-devel
BuildRequires:  libmodplug-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  libmpcdec-devel
BuildRequires:  libmpg123-devel
BuildRequires:  libogg-devel
BuildRequires:  libpulse-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libshout-devel
BuildRequires:  libsoup-devel
BuildRequires:  libvorbis-devel
%if 0%{?suse_version} >= 1140
BuildRequires:  libyajl1-devel
%endif
BuildRequires:  openal-soft-devel
BuildRequires:  sqlite3-devel
%if 0%{?suse_version} >= 1210
BuildRequires:  systemd-devel
%endif
BuildRequires:  udev
BuildRequires:  wavpack-devel
BuildRequires:  xmlto
%if 0%{?suse_version} >= 1130
BuildRequires:  zziplib-devel
%endif
%if 0%{?suse_version} < 1130
BuildRequires:  libzziplib-devel
%endif
BuildRequires:  zip
%if 0%{?suse_version} >= 1120
BuildRequires:  libgme-devel
%endif

%description
A daemon for playing music (mp3, ogg vorbis, flac, and wav).  Music is
played through the server's audio device.  The daemon stores info
about all available music, and this info can be easily searched and
retrieved.  Player control, info retrieval, and playlist management
can all be managed remotely. There a bunch of clients to control mpd:
for Gnome, KDE, console and Apache (PHP).

Please read README.mpd how to configure it.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2
%patch10 -p1

%build
export SUSE_ASNEEDED=0
%configure \
        --enable-debug \
        --enable-ao \
        --enable-audiofile \
        --enable-bzip2 \
        --enable-cdio-paranoia \
        --enable-curl \
        --enable-soup \
        --enable-ffmpeg \
        --enable-flac \
%if 0%{?suse_version} > 1100
        --enable-fluidsynth \
%endif
        --enable-httpd-output \
        --enable-id3 \
        --enable-iso9660 \
        --enable-jack \
        --enable-lastfm \
        --enable-libwrap \
        --enable-lsr \
        --enable-mikmod \
        --enable-mms \
        --enable-mvp \
        --enable-openal \
        --enable-pulse \
        --enable-recorder-output \
        --enable-shout \
        --enable-sqlite \
%if 0%{?suse_version} >= 1210
        --enable-systemd-daemon \
%endif
        --enable-vorbis \
        --enable-vorbis-encoder \
        --enable-wave-encoder \
        --enable-wavpack \
        --enable-zzip

make %{?_smp_mflags}

%install
%makeinstall docdir=%{_docdir}/%{name}
# missing dirs
install -d \
        %{buildroot}/var/lib/mpd/playlists \
        %{buildroot}%{_sbindir}
# additional docs
install -m 0644 %{SOURCE2} \
        AUTHORS COPYING NEWS README UPGRADING  \
        %{buildroot}%{_docdir}/%{name}/
# init scripts
install -D %{SOURCE1} %{buildroot}/etc/init.d/mpd
ln -s -f ../../etc/init.d/mpd %{buildroot}%{_sbindir}/rcmpd
# copy example mpd.conf
cp %{buildroot}%{_docdir}/%{name}/mpdconf.example %{buildroot}/etc/mpd.conf
cp -a "%{SOURCE3}" "%{buildroot}%{_docdir}/%{name}/"

%if 0%{?suse_version} >= 1210
# do not use the mpd-supplied service file
#%__install -D -m0644 mpd.service "%{buildroot}/lib/systemd/system/%{name}.service"
%__install -D -m0644 %{S:4} %{buildroot}/%{_unitdir}/%{name}.service
%endif

%clean
rm -rf "%{buildroot}"

%pre
# add mpd user only when installing first time
if [ "$1" = "1" ]; then
    useradd -G audio -s /bin/false -r -c "mpd user to run Music Player Daemon" \
        -d "%{_localstatedir}/lib/%{name}" mpd &>/dev/null; true
fi

%post
%{fillup_and_insserv -f mpd}

%preun
%stop_on_removal mpd

%postun
# remove mpd user when uninstalling package
if [ "$1" = "0" ]; then
   userdel mpd &> /dev/null; true
fi
%restart_on_update mpd
%insserv_cleanup

%files
%defattr(-,root,root)
%attr(0644,root,root) %config(noreplace) /etc/%{name}.conf
%{_bindir}/%{name}
%{_sbindir}/rcmpd
%attr(0755,root,root) /etc/init.d/%{name}
%attr(0755,mpd,audio) %{_localstatedir}/lib/%{name}
%{_mandir}/man1/%{name}.1*
%{_mandir}/man5/%{name}.conf.5*
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}
%if 0%{?suse_version} >= 1210
%{_unitdir}/%{name}.service
%endif

%changelog
* Fri Nov  8 2013 obs@botter.cc
- add Type=forking to mpd.service
* Fri Sep 20 2013 obs@botter.cc
- Update to 0.17.5:
  * protocol:
  - fix "playlistadd" with URI
  - fix "move" relative to current when there is no current song
  * decoder:
  - ffmpeg: support "application/flv"
  - mikmod: adapt to libmikmod 3.2
  * configure.ac:
  - detect system "ar"
- use gentoo's patch for compiling with ffmpeg 2.x
- add own service file (PM-79)
* Tue Jun 18 2013 fisiu@opensuse.org
- Update to 0.17.4:
  * protocol:
  - allow to omit END in ranges (START:END)
  - don't emit IDLE_PLAYER before audio format is known
  * decoder:
  - ffmpeg: support float planar audio (ffmpeg 1.1)
  - ffmpeg: fix AVFrame allocation
  * player:
  - implement missing "idle" events on output errors
  * clock: fix build failure
* Thu Mar 28 2013 fisiu@opensuse.org
- Update to 0.17.3:
  * output:
  - osx: fix pops during playback
  - recorder: fix I/O error check
  - shout: fix memory leak in error handler
  - recorder, shout: support Ogg packets that span more than one page
  * decoder:
  - ffmpeg: ignore negative time stamps
  - ffmpeg: support planar audio
  * playlist:
  - cue: fix memory leak
  - cue: fix CUE files with only one track
- Drop mpd-systemd_require_network_first.patch: fixed upstream.
* Thu Feb 14 2013 zaitor@opensuse.org
- Add explicit pkgconfig(bzip2) BuildRequires for 12.3 and newer.
* Fri Oct 19 2012 pascal.bleser@opensuse.org
- disable roaraudio support, pulls in ridiculous deps
* Fri Oct 19 2012 pascal.bleser@opensuse.org
- fix systemd unit script to require network to be started prior to
  mpd, thanks to Jean Delvare for the patch
- update to 0.17.2:
  * protocol:
  - fix crash in local file check
  * decoder:
  - fluidsynth: remove throttle (requires libfluidsynth 1.1)
  - fluidsynth: stop playback at end of file
  - fluidsynth: check MIDI file format while scanning
  - fluidsynth: add sample rate setting
  - wavpack: support all APEv2 tags
  * output:
  - httpd: use monotonic clock, avoid hiccups after system clock adjustment
  - httpd: fix throttling bug after resuming playback
  * playlist:
  - cue: map "PERFORMER" to "artist" or "album artist"
  * mapper: fix non-UTF8 music directory name
  * mapper: fix potential crash in file permission check
  * playlist: fix use-after-free bug
  * playlist: fix memory leak
  * state_file: save song priorities
  * player: disable cross-fading in "single" mode
  * update: fix unsafe readlink() usage
- changes from 0.17.1:
  * protocol:
  - require appropriate permissions for searchadd{,pl}
  * tags:
  - aiff: support the AIFC format
  - ape: check for ID3 if no usable APE tag was found
  * playlist:
  - cue: support file types "MP3", "AIFF"
  * output:
  - fix noisy playback with conversion and software volume
* Tue Jul 17 2012 pascal.bleser@opensuse.org
- update to 0.17:
  * protocol:
  - support client-to-client communication
  - "update" and "rescan" need only "CONTROL" permission
  - new command "seekcur" for simpler seeking within current song
  - new command "config" dumps location of music directory
  - add range parameter to command "load"
  - print extra "playlist" object for embedded CUE sheets
  - new commands "searchadd", "searchaddpl"
  * input:
  - cdio_paranoia: new input plugin to play audio CDs
  - curl: enable CURLOPT_NETRC
  - curl: non-blocking I/O
  - soup: new input plugin based on libsoup
  * tags:
  - RVA2: support separate album/track replay gain
  * decoder:
  - mpg123: implement seeking
  - ffmpeg: drop support for pre-0.5 ffmpeg
  - ffmpeg: support WebM
  - oggflac: delete this obsolete plugin
  - dsdiff: new decoder plugin
  * output:
  - alsa: support DSD-over-USB (dCS suggested standard)
  - httpd: support for streaming to a DLNA client
  - openal: improve buffer cancellation
  - shout: add possibility to set url
  - roar: new output plugin for RoarAudio
  * mixer:
  - alsa: listen for external volume changes
  * playlist:
  - allow references to songs outside the music directory
  - new CUE parser, without libcue
  - soundcloud: new plugin for accessing soundcloud.com
  * state_file: add option "restore_paused"
  * cue: show CUE track numbers
  * allow port specification in "bind_to_address" settings
  * support floating point samples
  * systemd socket activation
  * improve --version output
* Sun May  6 2012 fisiu@opensuse.org
- Update to 0.16:8:
  * fix for libsamplerate assertion failure
  * decoder:
  - vorbis (and others): fix seeking at startup
  - ffmpeg: read the "year" tag
  * encoder:
  - vorbis: generate end-of-stream packet before tag
  - vorbis: generate end-of-stream packet when playback ends
  * output:
  - jack: check for connection failure before starting playback
  - jack: workaround for libjack1 crash bug
  - osx: fix stuttering due to buffering bug
  * fix endless loop in text file reader
  * update: skip symlinks in path that is to be updated
- spec-cleaner'ed spec file
* Mon Feb  6 2012 pascal.bleser@opensuse.org
- update to 0.16.7:
  * input:
  - ffmpeg: support libavformat 0.7
  * decoder:
  - ffmpeg: support libavformat 0.8, libavcodec 0.9
  - ffmpeg: support all MPD tags
  * output:
  - httpd: fix excessive buffering
  - openal: force 16 bit playback, as 8 bit doesn't work
  * fix moving after current song
- add mpd-user.conf to doc files, copy to ~/.mpd/mpd.conf for user centric
  setup
- add tcpd and mkisofs support
* Thu Dec 22 2011 detlef@links2linux.de
- new upstream version <0.16.6>
* Sun Oct 23 2011 detlef@links2linux.de
- new upstream version <0.16.5>
* Fri Oct  7 2011 detlef@links2linux.de
- new upstream version <0.16.4>
* Fri Aug  5 2011 detlef@links2linux.de
- new upstream version <0.16.3>
* Thu Mar 24 2011 detlef@links2linux.de
- new upstream version <0.16.2>
* Fri Jan 14 2011 detlef@links2linux.de
- new upstream version <0.16.1>
* Sun Dec 12 2010 detlef@links2linux.de
- new upstream version <0.16>
* Sat Nov 13 2010 detlef@links2linux.de
- new upstream version <0.15.15>
* Wed Oct 13 2010 detlef@links2linux.de
- new upstream version <0.15.13>
  * output_thread: fix race condition after CANCEL command
  * output:
  - httpd: fix random data in stream title
  - httpd: MIME type audio/ogg for Ogg Vorbis
  * input:
  - rewind: update MIME not only once
  - rewind: enable for MMS
* Wed Jul 21 2010 detlef@links2linux.de
- new upstream version <0.15.12>
  * input:
  - curl: remove assertion after curl_multi_fdset()
  * tags:
  - rva2: set "gain", not "peak"
  * decoders:
  - wildmidi: support version 0.2.3
* Fri Jul 16 2010 detlef@links2linux.de
- new upstream version <0.15.11>
  * tags:
  - ape: support album artist
  * decoders:
  - mp4ff: support tags "album artist", "albumartist", "band"
  - mikmod: fix memory leak
  - vorbis: handle uri==NULL
  - ffmpeg: fix memory leak
  - ffmpeg: free AVFormatContext on error
  - ffmpeg: read more metadata
  - ffmpeg: fix libavformat 0.6 by using av_open_input_stream()
  * playlist: emit IDLE_OPTIONS when resetting single mode
  * listen: make get_remote_uid() work on BSD
* Mon May 31 2010 detlef@links2linux.de
- new upstream version <0.15.10>
  * input:
  - mms: fix memory leak in error handler
  - mms: initialize the "eof" attribute
  * decoders:
  - mad: properly calculate ID3 size without libid3tag
* Tue Mar 23 2010 detlef@links2linux.de
- new upstream version <0.15.9>
  * decoders:
  - mad: fix crash when seeking at end of song
  - mpcdec: fix negative shift on fixed-point samples
  - mpcdec: fix replay gain formula with v8
  * playlist: fix single+repeat in random mode
  * player: postpone song tags during cross-fade
* Wed Jan 27 2010 detlef@links2linux.de
- new upstream version <0.15.8>
  * input:
  - curl: allow rewinding with Icy-Metadata
  * decoders:
  - ffmpeg, flac, vorbis: added more flac/vorbis MIME types
  - ffmpeg: enabled libavformat's file name extension detection
  * dbUtils: return empty tag value only if no value was found
  * decoder_thread: fix CUE track playback
  * queue: don't repeat current song in consume mode
* Tue Jan 12 2010 detlef@links2linux.de
- fix init script
* Tue Dec 29 2009 detlef@links2linux.de
- new upstream version <0.15.7>
  * archive:
  - close archive when stream is closed
  - iso, zip: fixed memory leak in destructor
  * input:
  - file: don't fall back to parent directory
  - archive: fixed memory leak in error handler
  * tags:
  - id3: fix ID3v1 charset conversion
  * decoders:
  - eliminate jitter after seek failure
  - ffmpeg: don't try to force stereo
  - wavpack: allow fine-grained seeking
  * mixer: explicitly close all mixers on shutdown
  * mapper: fix memory leak when playlist_directory is not set
  * mapper: apply filesystem_charset to playlists
  * command: verify playlist name in the "rm" command
  * database: return multiple tag values per song
* Fri Nov 20 2009 detlef@links2linux.de
- new upstream version <0.15.6>
  * input:
  - lastfm: fixed variable name in GLib<2.16 code path
  - input/mms: require libmms 0.4
  * archive:
  - zzip: require libzzip 0.13
  * tags:
  - id3: allow 4 MB RIFF/AIFF tags
  * decoders:
  - ffmpeg: convert metadata
  - ffmpeg: align the output buffer
  - oggflac: rewind stream after FLAC detection
  - flac: fixed CUE seeking range check
  - flac: fixed NULL pointer dereference in CUE code
  * output_thread: check again if output is open on PAUSE
  * update: delete ignored symlinks from database
  * database: increased maximum line length to 32 kB
* Wed Oct 21 2009 detlef@links2linux.de
- new upstream version <0.15.5>
  * input:
  - curl: don't abort if a packet has only metadata
  - curl: fixed endless loop during buffering
  * tags:
  - riff, aiff: fixed "limited range" gcc warning
  * decoders:
  - flac: fixed two memory leaks in the CUE tag loader
  * decoder_thread: change the fallback decoder name to "mad"
  * output_thread: check again if output is open on CANCEL
  * update: fixed memory leak during container scan
* Tue Sep  1 2009 detlef@links2linux.de
- new upstream version <0.15.3>
  * Document nextsong and nextsongid
  * update: don't re-read unchanged container files
  * output_init: initialize the "pause" flag
  * decoder/vorbis: faster tag scanning with ov_test_callback()
* Tue Aug 18 2009 detlef@links2linux.de
- new upstream version <0.15.2>
  * tags:
  - ape: check the tag size (fixes integer underflow)
  - ape: added protection against large memory allocations
  * decoders:
  - mad: skip ID3 frames when libid3tag is disabled
  - flac: parse all replaygain tags
  - flac: don't allocate cuesheet twice (memleak)
  * output:
  - shout: fixed stuck pause bug
  - shout: minimize the unpause latency
  * update: free empty path string (memleak)
  * update: free temporary string in container scan (memleak)
  * directory: free empty directories after removing them (memleak)
* Sat Jul 18 2009 detlef@links2linux.de
- new upstream version <0.15.1>
* Sat Feb 14 2009 detlef@links2linux.de
- new upstream version <0.14.2>
  * Modify version string to post-release version 0.14.2~git
  * mpd version 0.14.2
  * ffmeg: added support for the tags comment, genre, year
  * mikmod: call MikMod_Exit() only in the finish() method
  * jack: register ports before activating clients
  * jack: allocate ring buffers before connecting
  * jack: clear "shutdown" flag on reconnect
  * jack: reduced sleep time to 1ms
  * mapper: remove trailing slashes from music_directory
  * mapper: ignore duplicate slashes in playlists
  * wavpack: pass NULL if the .wvc file fails to open
  * player_thread: set player error when output device fails
  * shout_mp3: free the lame_data struct on exit
  * shout_mp3: call lame_close() in clear_encoder() method
  * ffmpeg: print codec name
  * ffmpeg: don't warn of empty packet output
  * ffmpeg: check if the time stamp is valid
  * ffmpeg: fixed seek integer overflow
  * shout: removed shout_data.shout_error
  * shout: removed shout_data.tag_to_send
  * shout: switch to blocking mode
  * shout: use libshout's synchronization
  * shout: don't postpone metadata
  * shout: clear buffer before calling the encoder
  * configure.ac: define HAVE_FFMPEG after all checks
  * ffmpeg: added TTA support
  * aac: fix stream metadata
  * update: recursively purge deleted directories
  * update: free deleted subdirectories
  * ffmpeg: enable WAV streaming
* Mon Jan 19 2009 detlef@links2linux.de
- new upstream version <0.14.1>
  * decoders:
  - mp4: support the writer/composer tag
  - id3: strip leading and trailing whitespace from ID3 tags
  - oggvorbis: fix tremor support
  - oggvorbis: disable seeking on remote files
  * audio outputs:
  - jack: allocate default port names (fixes a crash)
  * update:
  - refresh stats after update
  - save the database even if it is empty
  * input_curl:
  - use select() to eliminate busy loop during connect
  - honour http_proxy_* config directives
  - fix assertion failure on "connection refused"
  - fix assertion failure with empty HTTP responses
  * corrected the sample calculation in the fallback resampler
  * log: automatically append newline
  * fix setenv() conflict on Solaris
  * configure.ac: check for pkg-config before using it
  * fix minor memory leak in decoder_tag()
  * fix cross-fading bug: it used to play some chunks of the new song twice
  * playlist
  - fix assertion failure during playlist load
  - implement Fisher-Yates shuffle properly
  - safely search the playlist for deleted song
  * use custom PRNG for volume dithering (speedup)
  * detect libid3tag without pkg-config
* Sat Dec 27 2008 detlef@links2linux.de
- new upstream version <0.14>
* Fri Jun 20 2008 detlef@links2linux.de
- new upstream version <0.13.2>
* Wed Jan 30 2008 detlef@links2linux.de
- new upstream version <0.13.1>
* Fri Jul 13 2007 detlef@links2linux.de
- add BuildRequires: libmikmod
- add BuildRequires: libmikmod-devel for > 1020
* Tue May 29 2007 detlef@links2linux.de
- new upstream version <0.13.0>
* Mon Mar 26 2007 detlef@links2linux.de
- new upstream version
* Mon Nov 13 2006 detlef@links2linux.de
- no resmgr for 10.2, use group audio
* Fri Oct 13 2006 detlef@links2linux.de
- new upstream version
* Thu Sep 28 2006 detlef@links2linux.de
- new upstream version
* Mon Sep 25 2006 detlef@links2linux.de
- new upstream version
* Sat Sep  2 2006 detlef@links2linux.de
- new upstream version
* Sun Aug 20 2006 detlef@links2linux.de
- new upstream version
* Fri Aug 11 2006 detlef@links2linux.de
- new upstream version
* Fri Jul 28 2006 detlef@links2linux.de
- new SVN-Snapshot
* Mon Dec  5 2005 malakhanov@gmx.de
- finally force mpd to work with resmgr
* Mon Jul 11 2005 malakhanov@gmx.de
- modified for x64 build
* Mon Mar 22 2004 malakhanov@gmx.de
- modified for SUSE/Packman. Init script courtesy of  Davide Lucchesi <odiobill@despammed.com>, 2003
* Wed Mar 10 2004 gbpeck@sbcglobal.net
- Rebuild for official release
* Mon Mar  8 2004 gbpeck@sbcglobal.net
- Version 0.10.1
* Wed Mar  3 2004 gbpeck@sbcglobal.net
- Version 0.10.0
- Add audiofile-devel builddep (for wav support)
- Add AUTHORS to docs
* Fri Feb  6 2004 gbpeck@sbcglobal.net
- Rebuild with mach
* Wed Jan 21 2004 gbpeck@sbcglobal.net
- Version 0.9.4
* Thu Oct 30 2003 gbpeck@sbcglobal.net
- Version 0.9.3
* Tue Oct  7 2003 gbpeck@sbcglobal.net
- Version 0.9.2
* Tue Sep 30 2003 gbpeck@sbcglobal.net
- Version 0.9.1
- Add BuildRequires on alsa-lib-devel
- Add versioned Requires on libao and libao-devel (from the debian
  control file)
* Thu Sep  4 2003 gbpeck@sbcglobal.net
- Version 0.8.7
* Mon Aug 18 2003 gbpeck@sbcglobal.net
- Version 0.8.5
* Thu Aug 14 2003 gbpeck@sbcglobal.net
- Initial build
